Package: scLang
Type: Package
Title: A unified language for interacting with Seurat and
        SingleCellExperiment
Version: 1.1.0
Authors@R: person('Andrei-Florian', 'Stoica', 
      email='andreistoica@foxmail.com',
     role=c('aut','cre'),
     comment=c(ORCID='0000-0002-5253-0826'))
Description: scLang is a suite for package development for scRNA-seq analysis. 
    It offers functions that can operate on both Seurat and 
    SingleCellExperiment objects. These functions are primarily aimed to help 
    developers build tools compatible with both types of input.
License: MIT + file LICENSE
Imports: dplyr, ggplot2, henna, methods, paletteer, rlang, S4Vectors,
        SeuratObject, SingleCellExperiment, stats, SummarizedExperiment
Suggests: BiocStyle, knitr, qs2, rmarkdown, scater, scRNAseq, Seurat,
        testthat (>= 3.0.0)
biocViews: Software, SingleCell, GeneExpression, Visualization
Encoding: UTF-8
URL: https://github.com/andrei-stoica26/scLang
BugReports: https://github.com/andrei-stoica26/scLang/issues
RoxygenNote: 7.3.3
VignetteBuilder: knitr
Config/testthat/edition: 3
git_url: https://git.bioconductor.org/packages/scLang
git_branch: devel
git_last_commit: c70c598
git_last_commit_date: 2026-04-28
Repository: Bioconductor 3.24
Date/Publication: 2026-04-28
NeedsCompilation: no
Packaged: 2026-04-29 00:58:30 UTC; biocbuild
Author: Andrei-Florian Stoica [aut, cre] (ORCID:
    <https://orcid.org/0000-0002-5253-0826>)
Maintainer: Andrei-Florian Stoica <andreistoica@foxmail.com>
