scePath <- system.file('extdata', 'sceObj.qs2', package='scLang')
sceObj <- qs2::qs_read(scePath)
seuratPath <- system.file('extdata', 'seuratObj.qs2', package='scLang')
seuratObj <- qs2::qs_read(seuratPath)
