% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/generics.R, R/metadata.R
\name{scCol}
\alias{scCol}
\alias{scCol<-}
\alias{scCol.default}
\alias{scCol<-.default}
\alias{scCol.Seurat}
\alias{scCol<-.Seurat}
\alias{scCol.SingleCellExperiment}
\alias{scCol<-.SingleCellExperiment}
\title{Extract a metadata/coldata column from object.}
\usage{
scCol(scObj, col)

scCol(scObj, col) <- value

\method{scCol}{default}(scObj, col)

\method{scCol}{default}(scObj, col) <- value

\method{scCol}{Seurat}(scObj, col)

\method{scCol}{Seurat}(scObj, col) <- value

\method{scCol}{SingleCellExperiment}(scObj, col)

\method{scCol}{SingleCellExperiment}(scObj, col) <- value
}
\arguments{
\item{scObj}{A \code{Seurat} or \code{SingleCellExperiment} object.}

\item{col}{Column name.}

\item{value}{A vector to be added to the metadata/coldata of the
single-cell expression object.}
}
\value{
A vector.
}
\description{
This function extracts a metadata/coldata column from a \code{Seurat} or
\code{SingleCellExperiment} object.
}
\examples{
scePath <- system.file('extdata', 'sceObj.qs2', package='scLang')
sceObj <- qs2::qs_read(scePath)
v <- scCol(sceObj, 'Cluster')

}
