% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/counts_and_percentages.R
\name{scColPairCounts}
\alias{scColPairCounts}
\title{Extract counts from two columns of a single-cell expression
object}
\usage{
scColPairCounts(scObj, col1 = "seurat_clusters", col2 = "orig.ident")
}
\arguments{
\item{scObj}{A \code{Seurat} or \code{SingleCellExperiment} object.}

\item{col1}{Column as string.}

\item{col2}{Column as string.}
}
\value{
A data frame listing the counts of all combinations of pairs from
two categorical columns.
}
\description{
This function extracts count information from two columns of a single-cell
expression object.
}
\examples{
scePath <- system.file('extdata', 'sceObj.qs2', package='scLang')
sceObj <- qs2::qs_read(scePath)
scColPairCounts(sceObj, 'Cluster', 'Donor')

}
