% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/generics.R, R/metadata.R
\name{metadataDF}
\alias{metadataDF}
\alias{metadataDF.default}
\alias{metadataDF.Seurat}
\alias{metadataDF.SingleCellExperiment}
\title{Extract metadata from object as a data frame}
\usage{
metadataDF(scObj)

\method{metadataDF}{default}(scObj)

\method{metadataDF}{Seurat}(scObj)

\method{metadataDF}{SingleCellExperiment}(scObj)
}
\arguments{
\item{scObj}{A \code{Seurat} or \code{SingleCellExperiment} object.}
}
\value{
A metadata data frame.
}
\description{
This function extracts the metadata from a \code{Seurat} or
\code{SingleCellExperiment} object as a data frame.
}
\examples{
scePath <- system.file('extdata', 'sceObj.qs2', package='scLang')
sceObj <- qs2::qs_read(scePath)
df <- metadataDF(sceObj)

}
